@@ -6,16 +6,13 @@
  * Author: Guido Günther <agx@sigxcpu.org>
  */
 
-
-#include <gtk/gtk.h>
+#pragma once
 
 #include "quick-setting.h"
 
-#pragma once
-
 G_BEGIN_DECLS
 
-#define PHOSH_TYPE_CAFFEINE_QUICK_SETTING (phosh_caffeine_quick_setting_get_type ())
+#define PHOSH_TYPE_CAFFEINE_QUICK_SETTING phosh_caffeine_quick_setting_get_type ()
 
 G_DECLARE_FINAL_TYPE (PhoshCaffeineQuickSetting,
                       phosh_caffeine_quick_setting,
