@@ -6,15 +6,14 @@
  * Author: Teemu Ikonen <tpikonen@mailbox.org>
  */
 
-#include <gtk/gtk.h>
+#pragma once
 
 #include "quick-setting.h"
 
-#pragma once
-
 G_BEGIN_DECLS
 
-#define PHOSH_TYPE_DARK_MODE_QUICK_SETTING (phosh_dark_mode_quick_setting_get_type ())
+#define PHOSH_TYPE_DARK_MODE_QUICK_SETTING phosh_dark_mode_quick_setting_get_type ()
+
 G_DECLARE_FINAL_TYPE (PhoshDarkModeQuickSetting,
                       phosh_dark_mode_quick_setting,
                       PHOSH, DARK_MODE_QUICK_SETTING, PhoshQuickSetting)
