@@ -6,14 +6,13 @@
  * Author: Guido Günther <agx@sigxcpu.org>
  */
 
-#include "pomodoro-quick-setting.h"
 #include "phosh-plugin.h"
+#include "pomodoro-quick-setting.h"
 
-#include <gio/gio.h>
-#include <gtk/gtk.h>
 
 char **g_io_phosh_plugin_pomodoro_quick_setting_query (void);
 
+
 void
 g_io_module_load (GIOModule *module)
 {
@@ -25,11 +24,13 @@ g_io_module_load (GIOModule *module)
                                   10);
 }
 
+
 void
 g_io_module_unload (GIOModule *module)
 {
 }
 
+
 char **
 g_io_phosh_plugin_pomodoro_quick_setting_query (void)
 {
