@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2022 Purism SPC
- *               2025 Phosh.mobi e.V.
+ *               2023-2025 Phosh.mobi e.V.
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -17,15 +17,18 @@
 #include "sensor-proxy-manager.h"
 #include "util.h"
 
-#define INTERFACE_SETTINGS      "org.gnome.desktop.interface"
+#define INTERFACE_SCHEMA        "org.gnome.desktop.interface"
 #define HIGH_CONTRAST_THEME     "HighContrast"
 #define KEY_GTK_THEME           "gtk-theme"
 #define KEY_ICON_THEME          "icon-theme"
 
-#define PHOSH_SETTINGS          "sm.puri.phosh"
+#define PHOSH_SCHEMA            "sm.puri.phosh"
 #define KEY_AUTOMATIC_HC        "automatic-high-contrast"
 #define KEY_AUTOMATIC_HC_THRESHOLD  "automatic-high-contrast-threshold"
 
+#define POWER_SCHEMA "org.gnome.settings-daemon.plugins.power"
+#define KEY_AMBIENT_ENABLED "ambient-enabled"
+
 #define NUM_VALUES              3
 
 /**
@@ -40,6 +43,8 @@
 enum {
   PROP_0,
   PROP_SENSOR_PROXY_MANAGER,
+  PROP_AUTO_BRIGHTNESS_ENABLED,
+  PROP_LIGHT_LEVEL,
   LAST_PROP,
 };
 static GParamSpec *props[LAST_PROP];
@@ -48,13 +53,18 @@ static GParamSpec *props[LAST_PROP];
 typedef struct _PhoshAmbient {
   GObject                  parent;
 
-  gboolean                 claimed;
+  int                      claimed;
   PhoshSensorProxyManager *sensor_proxy_manager;
   GCancellable            *cancel;
 
   GSettings               *phosh_settings;
   GSettings               *interface_settings;
+  GSettings               *power_settings;
+  gboolean                 auto_hc;
   gboolean                 use_hc;
+  gboolean                 auto_brightness;
+  double                   light_level;
+  gboolean                 blanked;
 
   guint                    sample_id;
   GArray                  *values;
@@ -98,6 +108,12 @@ phosh_ambient_get_property (GObject    *object,
   case PROP_SENSOR_PROXY_MANAGER:
     g_value_set_object (value, self->sensor_proxy_manager);
     break;
+  case PROP_AUTO_BRIGHTNESS_ENABLED:
+    g_value_set_boolean (value, self->auto_brightness);
+    break;
+  case PROP_LIGHT_LEVEL:
+    g_value_set_double (value, self->light_level);
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
     break;
@@ -146,7 +162,7 @@ switch_theme (PhoshAmbient *self, gboolean use_hc)
 
 
 static gboolean
-on_ambient_light_level_sample (gpointer data)
+on_ambient_sample_for_hc (gpointer data)
 {
   PhoshAmbient *self = PHOSH_AMBIENT (data);
   double level, threshold;
@@ -176,15 +192,20 @@ on_ambient_light_level_sample (gpointer data)
 
 
 static void
-on_ambient_light_level_changed (PhoshAmbient            *self,
-                                GParamSpec              *pspec,
-                                PhoshSensorProxyManager *sensor)
+stop_high_contrast_sampling (PhoshAmbient *self)
 {
-  double level, hyst, threshold;
-  const char *unit;
+  g_clear_handle_id (&self->sample_id, g_source_remove);
+  g_array_set_size (self->values, 0);
+}
+
+
+static void
+check_high_contrast (PhoshAmbient *self, double level)
+{
+  double hyst, threshold;
   gboolean wants_hc;
 
-  if (!self->claimed)
+  if (!self->auto_hc)
     return;
 
   /* Currently sampling, ignoring changes */
@@ -192,19 +213,8 @@ on_ambient_light_level_changed (PhoshAmbient            *self,
     return;
 
   threshold = g_settings_get_uint (self->phosh_settings, KEY_AUTOMATIC_HC_THRESHOLD);
-  level = phosh_dbus_sensor_proxy_get_light_level (PHOSH_DBUS_SENSOR_PROXY (self->sensor_proxy_manager));
-  unit = phosh_dbus_sensor_proxy_get_light_level_unit (PHOSH_DBUS_SENSOR_PROXY (self->sensor_proxy_manager));
-
-  g_debug ("Ambient light changed: %f %s", level, unit);
-
-  if (g_ascii_strcasecmp (unit , "lux") != 0) {
-    /* For vendor values we don't know if small or large values mean bright or dark so be conservative */
-    g_warning_once ("Unknown light level unit %s", unit);
-    return;
-  }
-
   /* Use a bit of hysteresis to not switch too often around the threshold */
-  hyst = (self->use_hc) ? 0.9 : 1.1;
+  hyst = self->use_hc ? 0.9 : 1.1;
   threshold *= hyst;
 
   wants_hc = level > threshold;
@@ -216,140 +226,220 @@ on_ambient_light_level_changed (PhoshAmbient            *self,
   g_return_if_fail (self->sample_id == 0);
   g_return_if_fail (self->values->len == 0);
   g_array_append_val (self->values, level);
-  self->sample_id = g_timeout_add_seconds (1, on_ambient_light_level_sample, self);
-  g_source_set_name_by_id (self->sample_id, "[phosh] ambient_sample");
+  self->sample_id = g_timeout_add_seconds (1, on_ambient_sample_for_hc, self);
+  g_source_set_name_by_id (self->sample_id, "[phosh] ambient_sample_for_hc");
 }
 
 
 static void
-on_ambient_claimed (PhoshSensorProxyManager *sensor_proxy_manager,
-                    GAsyncResult            *res,
-                    PhoshAmbient            *self)
+on_ambient_light_level_changed (PhoshAmbient            *self,
+                                GParamSpec              *pspec,
+                                PhoshSensorProxyManager *sensor)
 {
+  double level;
+  const char *unit;
+  PhoshDBusSensorProxy *proxy;
+
+  if (!self->claimed)
+    return;
+
+  proxy = PHOSH_DBUS_SENSOR_PROXY (self->sensor_proxy_manager);
+  level = phosh_dbus_sensor_proxy_get_light_level (proxy);
+  unit = phosh_dbus_sensor_proxy_get_light_level_unit (proxy);
+  if (!unit || g_ascii_strcasecmp (unit, "lux") != 0) {
+    /* For vendor values we don't know if small or large values mean bright or dark so be conservative */
+    g_warning_once ("Unknown light level unit %s", unit);
+    return;
+  }
+
+  g_debug ("Ambient light changed: %.2f %s", level, unit);
+  if (!G_APPROX_VALUE (self->light_level, level, FLT_EPSILON)) {
+    self->light_level = level;
+    g_object_notify_by_pspec (G_OBJECT (self), props[PROP_LIGHT_LEVEL]);
+  }
+
+  check_high_contrast (self, level);
+}
+
+
+static void
+update_auto_brightness_enabled (PhoshAmbient *self)
+{
+  gboolean auto_brightness;
+
+  g_return_if_fail (self->claimed >= 0);
+
+  auto_brightness = (self->claimed &&
+                     g_settings_get_boolean (self->power_settings, KEY_AMBIENT_ENABLED));
+
+  if (self->auto_brightness == auto_brightness)
+    return;
+
+  self->auto_brightness = auto_brightness;
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_AUTO_BRIGHTNESS_ENABLED]);
+}
+
+
+static void
+on_ambient_claimed (GObject *source_object, GAsyncResult *res, gpointer user_data)
+{
+  PhoshDBusSensorProxy *proxy = PHOSH_DBUS_SENSOR_PROXY (source_object);
+  PhoshAmbient *self = PHOSH_AMBIENT (user_data);
   g_autoptr (GError) err = NULL;
   gboolean success;
 
-  success = phosh_dbus_sensor_proxy_call_claim_light_finish (
-    PHOSH_DBUS_SENSOR_PROXY (sensor_proxy_manager),
-    res, &err);
+  g_return_if_fail (PHOSH_IS_SENSOR_PROXY_MANAGER (proxy));
+  g_return_if_fail (proxy == PHOSH_DBUS_SENSOR_PROXY (self->sensor_proxy_manager));
 
+  success = phosh_dbus_sensor_proxy_call_claim_light_finish (proxy, res, &err);
   if (!success) {
     g_warning ("Failed to claim ambient sensor: %s", err->message);
     return;
   }
 
   g_debug ("Claimed ambient sensor");
-  self->claimed = TRUE;
+  self->claimed++;
 
+  update_auto_brightness_enabled (self);
   on_ambient_light_level_changed (self, NULL, self->sensor_proxy_manager);
 }
 
 
 static void
-on_ambient_released (PhoshSensorProxyManager *sensor_proxy_manager,
-                     GAsyncResult            *res,
-                     PhoshAmbient            *self)
+on_ambient_released (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
+  PhoshDBusSensorProxy *proxy = PHOSH_DBUS_SENSOR_PROXY (source_object);
+  PhoshAmbient *self = PHOSH_AMBIENT (user_data);
   g_autoptr (GError) err = NULL;
   gboolean success;
 
-  g_return_if_fail (PHOSH_IS_SENSOR_PROXY_MANAGER (sensor_proxy_manager));
-  g_return_if_fail (sensor_proxy_manager == self->sensor_proxy_manager);
+  g_return_if_fail (self->claimed > 0);
+  g_return_if_fail (PHOSH_IS_SENSOR_PROXY_MANAGER (proxy));
+  g_return_if_fail (proxy == PHOSH_DBUS_SENSOR_PROXY (self->sensor_proxy_manager));
 
-  success = phosh_dbus_sensor_proxy_call_release_light_finish (
-    PHOSH_DBUS_SENSOR_PROXY (sensor_proxy_manager),
-    res, &err);
-
-  if (!success) {
+  success = phosh_dbus_sensor_proxy_call_release_light_finish (proxy, res, &err);
+  if (success)
+    g_debug ("Released ambient light sensor");
+  else
     g_warning ("Failed to release ambient sensor: %s", err->message);
-    return;
-  }
 
-  g_debug ("Released ambient light sensor");
-  self->claimed = FALSE;
+  self->claimed--;
+  update_auto_brightness_enabled (self);
+  stop_high_contrast_sampling (self);
 }
 
 
 static void
 phosh_ambient_claim_light (PhoshAmbient *self, gboolean claim)
 {
-  if (claim == self->claimed)
+  PhoshDBusSensorProxy *proxy = PHOSH_DBUS_SENSOR_PROXY (self->sensor_proxy_manager);
+
+  if (claim == !!self->claimed)
     return;
 
+  g_debug ("Claiming sensor: %d", claim);
   if (claim) {
-    phosh_dbus_sensor_proxy_call_claim_light (
-      PHOSH_DBUS_SENSOR_PROXY (self->sensor_proxy_manager),
-      self->cancel,
-      (GAsyncReadyCallback)on_ambient_claimed,
-      self);
+    phosh_dbus_sensor_proxy_call_claim_light (proxy, self->cancel, on_ambient_claimed, self);
   } else {
-    g_clear_handle_id (&self->sample_id, g_source_remove);
-    g_array_set_size (self->values, 0);
-    phosh_dbus_sensor_proxy_call_release_light (
-      PHOSH_DBUS_SENSOR_PROXY (self->sensor_proxy_manager),
-      self->cancel,
-      (GAsyncReadyCallback)on_ambient_released,
-      self);
+    phosh_dbus_sensor_proxy_call_release_light (proxy, self->cancel, on_ambient_released, self);
   }
 }
 
 
 static void
-on_automatic_high_contrast_changed (PhoshAmbient *self,
-                                    GParamSpec   *pspec,
-                                    GSettings    *settings)
+maybe_claim (PhoshAmbient *self)
 {
-  gboolean enable;
+  gboolean auto_brightness, auto_hc, claim;
 
-  enable = g_settings_get_boolean (self->phosh_settings, KEY_AUTOMATIC_HC);
+  g_return_if_fail (self->claimed >= 0);
 
-  if (enable) {
-    if (self->claimed)
+  auto_brightness = g_settings_get_boolean (self->power_settings, KEY_AMBIENT_ENABLED);
+  auto_hc = g_settings_get_boolean (self->phosh_settings, KEY_AUTOMATIC_HC);
+  claim = auto_hc || auto_brightness;
+
+  g_debug ("Auto brightness enabled: %d, Auto HC enabled: %d, claim: %d",
+           auto_brightness, auto_hc, claim);
+
+  if (self->auto_hc == auto_hc &&
+      self->auto_brightness == auto_brightness &&
+      !!self->claimed == claim) {
+    return;
+  }
+
+  self->auto_hc = auto_hc;
+  update_auto_brightness_enabled (self);
+
+  if (claim) {
+    if (self->claimed) {
+      g_debug ("Already claimed, triggering update");
       on_ambient_light_level_changed (self, NULL, self->sensor_proxy_manager);
-    else
+    } else {
       phosh_ambient_claim_light (self, TRUE);
+    }
   } else {
     phosh_ambient_claim_light (self, FALSE);
     /* Switch back to normal theme */
-    switch_theme (self, FALSE);
+    if (!self->auto_hc)
+      switch_theme (self, FALSE);
   }
 }
 
 
 static void
-on_has_ambient_light_changed (PhoshAmbient            *self,
-                              GParamSpec              *pspec,
-                              PhoshSensorProxyManager *proxy)
+on_settings_changed (PhoshAmbient *self)
 {
-  gboolean has_ambient;
-
-  has_ambient = phosh_dbus_sensor_proxy_get_has_ambient_light (
-    PHOSH_DBUS_SENSOR_PROXY (self->sensor_proxy_manager));
-
-  g_debug ("Found %s ambient sensor", has_ambient ? "a" : "no");
-
-  on_automatic_high_contrast_changed (self, NULL, self->phosh_settings);
+  maybe_claim (self);
 }
 
 
 static void
-on_shell_state_changed (PhoshAmbient  *self,
-                        GParamSpec    *pspec,
-                        PhoshShell    *shell)
+on_has_ambient_light_changed (PhoshAmbient         *self,
+                              GParamSpec           *pspec,
+                              PhoshDBusSensorProxy *proxy)
 {
+  gboolean has_ambient;
+
+  g_return_if_fail (self->claimed >= 0);
+
+  has_ambient = phosh_dbus_sensor_proxy_get_has_ambient_light (proxy);
+  if (has_ambient) {
+    g_debug ("Ambient sensor appeared");
+    maybe_claim (self);
+    return;
+  }
+
+  if (!self->claimed)
+    return;
+
+  g_debug ("Ambient sensor disappeared, marking unclaimed");
+  self->claimed--;
+  update_auto_brightness_enabled (self);
+  stop_high_contrast_sampling (self);
+}
+
+
+static void
+on_shell_state_changed (PhoshAmbient *self, GParamSpec *pspec, PhoshShell *shell)
+{
+  gboolean blanked;
   PhoshShellStateFlags state;
 
   g_return_if_fail (PHOSH_IS_AMBIENT (self));
   g_return_if_fail (PHOSH_IS_SHELL (shell));
 
   state = phosh_shell_get_state (shell);
-  g_debug ("Shell state changed: %d", state);
-  /* Claim/unclaim the sensor on screen unblank / blank */
-  if (state & PHOSH_STATE_BLANKED) {
+  blanked = !!(state & PHOSH_STATE_BLANKED);
+
+  if (self->blanked == blanked)
+    return;
+  self->blanked = blanked;
+
+  g_debug ("Shell blanked: %d", self->blanked);
+  /* Claim / unclaim the sensor on screen unblank / blank */
+  if (blanked)
     phosh_ambient_claim_light (self, FALSE);
-  } else {
-    on_has_ambient_light_changed (self, NULL, self->sensor_proxy_manager);
-  }
+  else
+    maybe_claim (self);
 }
 
 
@@ -371,10 +461,10 @@ phosh_ambient_constructed (GObject *object)
 
   g_object_connect (self->phosh_settings,
                     "swapped-signal::changed::" KEY_AUTOMATIC_HC,
-                    G_CALLBACK (on_automatic_high_contrast_changed),
+                    G_CALLBACK (on_settings_changed),
                     self,
                     "swapped-signal::changed::" KEY_AUTOMATIC_HC_THRESHOLD,
-                    G_CALLBACK (on_automatic_high_contrast_changed),
+                    G_CALLBACK (on_settings_changed),
                     self,
                     NULL);
 
@@ -384,7 +474,12 @@ phosh_ambient_constructed (GObject *object)
                            self,
                            G_CONNECT_SWAPPED);
 
-  on_has_ambient_light_changed (self, NULL, self->sensor_proxy_manager);
+  g_signal_connect_swapped (self->power_settings,
+                            "changed::" KEY_AMBIENT_ENABLED,
+                            G_CALLBACK (on_settings_changed),
+                            self);
+
+  on_has_ambient_light_changed (self, NULL, PHOSH_DBUS_SENSOR_PROXY (self->sensor_proxy_manager));
 }
 
 
@@ -412,6 +507,8 @@ phosh_ambient_dispose (GObject *object)
   g_clear_handle_id (&self->fader_id, g_source_remove);
   g_clear_pointer (&self->fader, phosh_cp_widget_destroy);
 
+  g_clear_object (&self->power_settings);
+
   G_OBJECT_CLASS (phosh_ambient_parent_class)->dispose (object);
 }
 
@@ -431,9 +528,28 @@ phosh_ambient_class_init (PhoshAmbientClass *klass)
     g_param_spec_object ("sensor-proxy-manager", "", "",
                          PHOSH_TYPE_SENSOR_PROXY_MANAGER,
                          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+  /**
+   * PhoshAmbient:auto-brightness-enabled:
+   *
+   * If `TRUE` the display brightness should currently be adjusted to
+   * ambient light levels
+   */
+  props[PROP_AUTO_BRIGHTNESS_ENABLED] =
+    g_param_spec_boolean ("auto-brightness-enabled", "", "",
+                          FALSE,
+                          G_PARAM_READABLE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
+  /**
+   * PhoshAmbient:light-level:
+   *
+   * The last light level reading of the ambient light sensor.
+   */
+  props[PROP_LIGHT_LEVEL] =
+    g_param_spec_double ("light-level", "", "",
+                         0.0, G_MAXDOUBLE, 0.0,
+                         G_PARAM_READABLE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
+
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
-
 }
 
 
@@ -442,12 +558,16 @@ phosh_ambient_init (PhoshAmbient *self)
 {
   g_autofree char *theme_name = NULL;
 
+  /* Ensure initial sync */
+  self->light_level = -1.0;
+  self->blanked = -1;
   self->cancel = g_cancellable_new ();
 
   self->values = g_array_new (FALSE, FALSE, sizeof(double));
 
-  self->interface_settings = g_settings_new (INTERFACE_SETTINGS);
-  self->phosh_settings = g_settings_new (PHOSH_SETTINGS);
+  self->interface_settings = g_settings_new (INTERFACE_SCHEMA);
+  self->phosh_settings = g_settings_new (PHOSH_SCHEMA);
+  self->power_settings = g_settings_new (POWER_SCHEMA);
 
   /* Check whether we're already using the hc theme */
   theme_name = g_settings_get_string (self->interface_settings, KEY_GTK_THEME);
@@ -463,3 +583,21 @@ phosh_ambient_new (PhoshSensorProxyManager *sensor_proxy_manager)
                        "sensor-proxy-manager", sensor_proxy_manager,
                        NULL);
 }
+
+
+gboolean
+phosh_ambient_get_auto_brightness (PhoshAmbient *self)
+{
+  g_return_val_if_fail (PHOSH_IS_AMBIENT (self), FALSE);
+
+  return self->auto_brightness;
+}
+
+
+double
+phosh_ambient_get_light_level (PhoshAmbient *self)
+{
+  g_return_val_if_fail (PHOSH_IS_AMBIENT (self), FALSE);
+
+  return self->light_level;
+}
