@@ -12,6 +12,8 @@
 
 G_BEGIN_DECLS
 
+#define PHOSH_APP_AUTH_PROMPT_CHOICES_FORMAT "a(ssa(ss)s)"
+
 #define PHOSH_TYPE_APP_AUTH_PROMPT (phosh_app_auth_prompt_get_type ())
 
 G_DECLARE_FINAL_TYPE (PhoshAppAuthPrompt, phosh_app_auth_prompt, PHOSH, APP_AUTH_PROMPT, PhoshSystemModalDialog)
@@ -28,6 +30,4 @@ gboolean phosh_app_auth_prompt_get_grant_access (GtkWidget *self);
 GVariant* phosh_app_auth_prompt_get_selected_choices (GtkWidget *self);
 gboolean phosh_app_auth_prompt_get_remember (GtkWidget *self);
 
-#define CHOICES_FORMAT "a(ssa(ss)s)"
-
 G_END_DECLS
