@@ -10,6 +10,7 @@
 
 #include "launcher-entry-manager.h"
 #include "monitor-manager.h"
+#include "mpris-manager.h"
 #include "session-manager.h"
 #include "shell.h"
 #include "wifi-manager.h"
@@ -20,6 +21,7 @@ G_BEGIN_DECLS
 /* Created by the shell on startup */
 PhoshLauncherEntryManager *phosh_shell_get_launcher_entry_manager (PhoshShell *self);
 PhoshMonitorManager       *phosh_shell_get_monitor_manager (PhoshShell *self);
+PhoshMprisManager         *phosh_shell_get_mpris_manager   (PhoshShell *self);
 PhoshSessionManager       *phosh_shell_get_session_manager (PhoshShell *self);
 /* Created on the fly */
 PhoshWifiManager          *phosh_shell_get_wifi_manager    (PhoshShell *self);
