@@ -9,11 +9,18 @@
 #pragma once
 
 #include "lockscreen-manager.h"
+
 #include "dbus/phosh-screen-saver-dbus.h"
+
 #include <glib-object.h>
 
+G_BEGIN_DECLS
+
 #define PHOSH_TYPE_SCREEN_SAVER_MANAGER             (phosh_screen_saver_manager_get_type ())
+
 G_DECLARE_FINAL_TYPE (PhoshScreenSaverManager, phosh_screen_saver_manager, PHOSH, SCREEN_SAVER_MANAGER,
                       PhoshDBusScreenSaverSkeleton)
 
-PhoshScreenSaverManager * phosh_screen_saver_manager_new (PhoshLockscreenManager *lockscreen_manager);
+PhoshScreenSaverManager *phosh_screen_saver_manager_new (PhoshLockscreenManager *lockscreen_manager);
+
+G_END_DECLS
