@@ -6,6 +6,7 @@
 
 #pragma once
 
+#include "ambient.h"
 #include "app-tracker.h"
 #include "background-manager.h"
 #include "brightness-manager.h"
@@ -61,6 +62,7 @@ typedef enum {
  * @PHOSH_SHELL_DEBUG_FLAG_ALWAYS_SPLASH: always use splash (even when docked)
  * @PHOSH_SHELL_DEBUG_FLAG_FAKE_BUILTIN: When calculatiog layout treat the first
  *     virtual output like a built-in output.
+ * @PHOSH_SHELL_DEBUG_BACKLIGHT_NON_LINEAR: Assume backlight uses non-linear scale
  *
  * These flags are to enable/disable debugging features.
  */
@@ -68,6 +70,7 @@ typedef enum {
   PHOSH_SHELL_DEBUG_FLAG_NONE          = 0,
   PHOSH_SHELL_DEBUG_FLAG_ALWAYS_SPLASH = 1 << 0,
   PHOSH_SHELL_DEBUG_FLAG_FAKE_BUILTIN  = 1 << 1,
+  PHOSH_SHELL_DEBUG_BACKLIGHT_NON_LINEAR = 1 << 2,
 } PhoshShellDebugFlags;
 
 
@@ -79,6 +82,7 @@ void                 phosh_shell_unlock          (PhoshShell *self);
 void                 phosh_shell_set_primary_monitor (PhoshShell *self, PhoshMonitor *monitor);
 
 /* Created by the shell on startup */
+PhoshAmbient           *phosh_shell_get_ambient            (PhoshShell *self);
 PhoshAppTracker        *phosh_shell_get_app_tracker        (PhoshShell *self);
 PhoshBackgroundManager *phosh_shell_get_background_manager (PhoshShell *self);
 PhoshBrightnessManager *phosh_shell_get_brightness_manager (PhoshShell *self);
