@@ -12,7 +12,7 @@
 
 #include "phosh-config.h"
 
-#include "shell.h"
+#include "shell-priv.h"
 #include "wifi-info.h"
 
 /**
