@@ -7,6 +7,7 @@
 #pragma once
 
 #include <gtk/gtk.h>
+#include <handy.h>
 #include "util.h"
 #include "wifi-network.h"
 
@@ -14,7 +15,7 @@ G_BEGIN_DECLS
 
 #define PHOSH_TYPE_WIFI_NETWORK_ROW phosh_wifi_network_row_get_type ()
 G_DECLARE_FINAL_TYPE (PhoshWifiNetworkRow, phosh_wifi_network_row, PHOSH, WIFI_NETWORK_ROW,
-                      GtkListBoxRow)
+                      HdyActionRow)
 
 GtkWidget *phosh_wifi_network_row_new (PhoshWifiNetwork *network);
 
