@@ -1,4 +1,4 @@
-#include "config.h"
+#include "cui-config.h"
 
 #include <gtk/gtk.h>
 #include <call-ui.h>
@@ -42,7 +42,12 @@ main (int    argc,
   /* This is enough since libcall-ui performs the bindtextdomain */
   textdomain (GETTEXT_PACKAGE);
 
-  app = gtk_application_new ("org.gnome.CallUI.Demo", G_APPLICATION_FLAGS_NONE);
+  app = gtk_application_new ("org.gnome.CallUI.Demo",
+#if GLIB_CHECK_VERSION (2, 73, 3)
+                             G_APPLICATION_DEFAULT_FLAGS);
+#else
+                             G_APPLICATION_FLAGS_NONE);
+#endif
   g_signal_connect (app, "startup", G_CALLBACK (startup), NULL);
   g_signal_connect (app, "activate", G_CALLBACK (show_window), NULL);
   status = g_application_run (G_APPLICATION (app), argc, argv);
