@@ -89,6 +89,13 @@ phosh_shell_get_app_tracker (PhoshShell *self)
 }
 
 
+PhoshMprisManager *
+phosh_shell_get_mpris_manager (PhoshShell *self)
+{
+  return NULL;
+}
+
+
 PhoshWifiManager *
 phosh_shell_get_wifi_manager (PhoshShell *self)
 {
